@@ -1,7 +1,7 @@
 package Complete::Path;
 
 our $DATE = '2015-09-16'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -166,8 +166,6 @@ sub complete_path {
     my $result_prefix = $args{result_prefix};
     my $starting_path = $args{starting_path} // '';
 
-    my $exp_im_path_max_len = $Complete::Setting::OPT_EXP_IM_PATH_MAX_LEN;
-
     my $re_ends_with_path_sep = qr!\A\z|\Q$path_sep\E\z!;
 
     # split word by into path elements, as we want to dig level by level (needed
@@ -223,10 +221,10 @@ sub complete_path {
             my $re = do {
                 my $s = $intdir;
                 $s =~ s/_/-/g if $map_case;
-                $exp_im_path && length($s) <= $exp_im_path_max_len ?
+                $exp_im_path ?
                     ($ci ? qr/\A\Q$s/i : qr/\A\Q$s/) :
-                        ($ci ? qr/\A\Q$s\E(?:\Q$path_sep\E)?\z/i :
-                             qr/\A\Q$s\E(?:\Q$path_sep\E)?\z/);
+                    ($ci ? qr/\A\Q$s\E(?:\Q$path_sep\E)?\z/i :
+                     qr/\A\Q$s\E(?:\Q$path_sep\E)?\z/);
             };
             #say "D:  re=$re";
             my $num_exact_matches = 0;
@@ -340,7 +338,7 @@ Complete::Path - Complete path
 
 =head1 VERSION
 
-This document describes version 0.16 of Complete::Path (from Perl distribution Complete-Path), released on 2015-09-16.
+This document describes version 0.17 of Complete::Path (from Perl distribution Complete-Path), released on 2015-09-16.
 
 =head1 DESCRIPTION
 
